==> librejs-4.9.1.tar.gz: librejs-4.9.1/test/test-cors-bug.js <==
/**
 * GNU LibreJS - A browser add-on to block nonfree nontrivial JavaScript.
 * *
 * Copyright (C) 2011, 2012 Loic J. Duros
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see  <http://www.gnu.org/licenses/>.
 *
 */

var pageMod = require("page-mod");
var tabs = require("tabs");
var data = require("self").data;
var timer = require("timer");
exports.testCORS = function (test) { 
    test.waitUntilDone();
        
    var mod = pageMod.PageMod({
	include: /.*cors-test2.html/,
	contentScriptWhen: 'end',

	contentScript: "window.setTimeout(function () { " + 
            "var content = document.getElementById(\"cross\").innerHTML;" + 
            "if (/snippet/.test(content)) {"
            + "self.postMessage(\"Done!\");} "
            + "}, 5000); ",

	onAttach: function (worker) {

	    worker.on('message', function (message) {

                console.log("CORS bug test page fully loaded");

		if (message === 'Done!') {
                            test.assertEqual(true, true);
		            test.done();
		            mod.destroy();
		}
	    });
	}

    });

    tabs.open(data.url("test/cors-test2.html"));
    
};

==> librejs-5.4.1.tar.gz: librejs-5.4.1/test/test-cors-bug.js <==
/**
 * GNU LibreJS - A browser add-on to block nonfree nontrivial JavaScript.
 * *
 * Copyright (C) 2011, 2012 Loic J. Duros
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see  <http://www.gnu.org/licenses/>.
 *
 */

var pageMod = require("page-mod");
var tabs = require("sdk/tabs");
var data = require("sdk/self").data;
var timer = require("timer");
exports.testCORS = function (test) { 
    test.waitUntilDone();
        
    var mod = pageMod.PageMod({
	include: /.*cors-test2.html/,
	contentScriptWhen: 'end',

	contentScript: "window.setTimeout(function () { " + 
            "var content = document.getElementById(\"cross\").innerHTML;" + 
            "if (/snippet/.test(content)) {"
            + "self.postMessage(\"Done!\");} "
            + "}, 5000); ",

	onAttach: function (worker) {

	    worker.on('message', function (message) {

                console.log("CORS bug test page fully loaded");

		if (message === 'Done!') {
                            test.assertEqual(true, true);
		            test.done();
		            mod.destroy();
		}
	    });
	}

    });

    tabs.open(data.url("test/cors-test2.html"));
    
};
